==> epiphany-1.5.6.tar.gz: epiphany-1.5.6/lib/ephy-lib-type-builtins.c <==

/* Generated data (by glib-mkenums) */

#include "ephy-lib-type-builtins.h"



/* enumerations from "ephy-node.h" */
#include "ephy-node.h"
static const GEnumValue _ephy_node_signal_type_values[] = {
  { EPHY_NODE_DESTROY, "EPHY_NODE_DESTROY", "destroy" },
  { EPHY_NODE_RESTORED, "EPHY_NODE_RESTORED", "restored" },
  { EPHY_NODE_CHANGED, "EPHY_NODE_CHANGED", "changed" },
  { EPHY_NODE_CHILD_ADDED, "EPHY_NODE_CHILD_ADDED", "child-added" },
  { EPHY_NODE_CHILD_CHANGED, "EPHY_NODE_CHILD_CHANGED", "child-changed" },
  { EPHY_NODE_CHILD_REMOVED, "EPHY_NODE_CHILD_REMOVED", "child-removed" },
  { EPHY_NODE_CHILDREN_REORDERED, "EPHY_NODE_CHILDREN_REORDERED", "children-reordered" },
  { 0, NULL, NULL }
};

GType
ephy_node_signal_type_get_type (void)
{
  static GType type = 0;

  if (G_UNLIKELY (type == 0))
    type = g_enum_register_static ("EphyNodeSignalType", _ephy_node_signal_type_values);

  return type;
}



/* enumerations from "ephy-state.h" */
#include "ephy-state.h"
static const GFlagsValue _ephy_state_window_flags_values[] = {
  { EPHY_STATE_WINDOW_SAVE_NONE, "EPHY_STATE_WINDOW_SAVE_NONE", "none" },
  { EPHY_STATE_WINDOW_SAVE_SIZE, "EPHY_STATE_WINDOW_SAVE_SIZE", "size" },
  { EPHY_STATE_WINDOW_SAVE_POSITION, "EPHY_STATE_WINDOW_SAVE_POSITION", "position" },
  { 0, NULL, NULL }
};

GType
ephy_state_window_flags_get_type (void)
{
  static GType type = 0;

  if (G_UNLIKELY (type == 0))
    type = g_flags_register_static ("EphyStateWindowFlags", _ephy_state_window_flags_values);

  return type;
}



/* Generated data ends here */

==> epiphany-1.6.3.tar.gz: epiphany-1.6.3/lib/ephy-lib-type-builtins.c <==

/* Generated data (by glib-mkenums) */

#include "ephy-lib-type-builtins.h"



/* enumerations from "ephy-node.h" */
#include "ephy-node.h"
static const GEnumValue _ephy_node_signal_type_values[] = {
  { EPHY_NODE_DESTROY, "EPHY_NODE_DESTROY", "destroy" },
  { EPHY_NODE_RESTORED, "EPHY_NODE_RESTORED", "restored" },
  { EPHY_NODE_CHANGED, "EPHY_NODE_CHANGED", "changed" },
  { EPHY_NODE_CHILD_ADDED, "EPHY_NODE_CHILD_ADDED", "child-added" },
  { EPHY_NODE_CHILD_CHANGED, "EPHY_NODE_CHILD_CHANGED", "child-changed" },
  { EPHY_NODE_CHILD_REMOVED, "EPHY_NODE_CHILD_REMOVED", "child-removed" },
  { EPHY_NODE_CHILDREN_REORDERED, "EPHY_NODE_CHILDREN_REORDERED", "children-reordered" },
  { 0, NULL, NULL }
};

GType
ephy_node_signal_type_get_type (void)
{
  static GType type = 0;

  if (G_UNLIKELY (type == 0))
    type = g_enum_register_static ("EphyNodeSignalType", _ephy_node_signal_type_values);

  return type;
}



/* enumerations from "ephy-state.h" */
#include "ephy-state.h"
static const GFlagsValue _ephy_state_window_flags_values[] = {
  { EPHY_STATE_WINDOW_SAVE_NONE, "EPHY_STATE_WINDOW_SAVE_NONE", "none" },
  { EPHY_STATE_WINDOW_SAVE_SIZE, "EPHY_STATE_WINDOW_SAVE_SIZE", "size" },
  { EPHY_STATE_WINDOW_SAVE_POSITION, "EPHY_STATE_WINDOW_SAVE_POSITION", "position" },
  { 0, NULL, NULL }
};

GType
ephy_state_window_flags_get_type (void)
{
  static GType type = 0;

  if (G_UNLIKELY (type == 0))
    type = g_flags_register_static ("EphyStateWindowFlags", _ephy_state_window_flags_values);

  return type;
}



/* enumerations from "ephy-dbus.h" */
#include "ephy-dbus.h"
static const GEnumValue _ephy_dbus_bus_values[] = {
  { EPHY_DBUS_SESSION, "EPHY_DBUS_SESSION", "session" },
  { EPHY_DBUS_SYSTEM, "EPHY_DBUS_SYSTEM", "system" },
  { 0, NULL, NULL }
};

GType
ephy_dbus_bus_get_type (void)
{
  static GType type = 0;

  if (G_UNLIKELY (type == 0))
    type = g_enum_register_static ("EphyDbusBus", _ephy_dbus_bus_values);

  return type;
}



/* Generated data ends here */
